pub struct ParagraphComponent {
pub text_list: Vec<TextComponent>,
}Expand description
ParagraphComponent : A list of rich text content, usually presented in a text box.
Fields
text_list: Vec<TextComponent>Implementations
sourceimpl ParagraphComponent
impl ParagraphComponent
sourcepub fn new(text_list: Vec<TextComponent>) -> ParagraphComponent
pub fn new(text_list: Vec<TextComponent>) -> ParagraphComponent
A list of rich text content, usually presented in a text box.